# SWE-bench Lite 10-Task Batch Report

Generated: 2026-03-26T17:05:00.539415

- Total instances: **10**
- Official test patch applied: **10 / 10**
- Candidate patch applied: **2 / 10**
- Target improved (baseline FAIL_TO_PASS failed and patched passed): **1 / 10**

| Instance | Repo | Official Patch | Candidate Patch | Target Improved | FAIL_TO_PASS | PASS_TO_PASS |
|---|---|---:|---:|---:|---:|---:|
| marshmallow-code__marshmallow-1343 | marshmallow-code/marshmallow | True | False | False | 4 -> 999 | 998 -> 998 |
| marshmallow-code__marshmallow-1359 | marshmallow-code/marshmallow | True | False | False | 4 -> 999 | 998 -> 998 |
| pvlib__pvlib-python-1072 | pvlib/pvlib-python | True | False | False | 1 -> 999 | 998 -> 998 |
| pvlib__pvlib-python-1606 | pvlib/pvlib-python | True | False | False | 1 -> 999 | 998 -> 998 |
| pvlib__pvlib-python-1707 | pvlib/pvlib-python | True | False | False | 1 -> 999 | 998 -> 998 |
| sqlfluff__sqlfluff-1517 | sqlfluff/sqlfluff | True | True | False | 4 -> 4 | 998 -> 998 |
| sqlfluff__sqlfluff-1625 | sqlfluff/sqlfluff | True | False | False | 1 -> 999 | 998 -> 998 |
| sqlfluff__sqlfluff-1733 | sqlfluff/sqlfluff | True | False | False | 1 -> 999 | 0 -> 999 |
| sqlfluff__sqlfluff-1763 | sqlfluff/sqlfluff | True | False | False | 1 -> 999 | 998 -> 998 |
| sqlfluff__sqlfluff-2419 | sqlfluff/sqlfluff | True | True | True | 1 -> 0 | 0 -> 0 |
